==> reverie_dreams-0.4.3%2B1.21.7%2Bbeta-sources.jar: cc/thonly/reverie_dreams/entity/MushroomMonsterEntity.java <==
package cc.thonly.reverie_dreams.entity;

import cc.thonly.reverie_dreams.Touhou;
import cc.thonly.reverie_dreams.util.entity.AnimationHelper;
import cc.thonly.reverie_dreams.util.entity.ModelUtil;
import de.tomalbrc.bil.api.AnimatedEntity;
import de.tomalbrc.bil.api.AnimatedEntityHolder;
import de.tomalbrc.bil.core.holder.entity.EntityHolder;
import de.tomalbrc.bil.core.holder.entity.living.LivingEntityHolder;
import de.tomalbrc.bil.core.model.Model;
import eu.pb4.polymer.virtualentity.api.attachment.EntityAttachment;
import lombok.Getter;
import net.minecraft.class_1282;
import net.minecraft.class_1293;
import net.minecraft.class_1294;
import net.minecraft.class_1297;
import net.minecraft.class_1299;
import net.minecraft.class_1309;
import net.minecraft.class_1314;
import net.minecraft.class_1347;
import net.minecraft.class_1361;
import net.minecraft.class_1366;
import net.minecraft.class_1376;
import net.minecraft.class_1394;
import net.minecraft.class_1400;
import net.minecraft.class_1542;
import net.minecraft.class_1657;
import net.minecraft.class_1792;
import net.minecraft.class_1799;
import net.minecraft.class_1802;
import net.minecraft.class_1937;
import net.minecraft.class_3218;
import net.minecraft.class_5132;
import net.minecraft.class_5134;
import net.minecraft.class_5819;
import net.minecraft.class_7;
import net.minecraft.entity.ai.goal.*;
import java.util.WeakHashMap;

@Getter
public class MushroomMonsterEntity extends class_1314 implements AnimatedEntity {
    public static final WeakHashMap<class_1297, EntityHolder<MushroomMonsterEntity>> ELEMENTS = new WeakHashMap<>();
    public static final Model MODEL = ModelUtil.loadModel(Touhou.id("mushroom_monster"));
    private final Model hairballModel;
    private EntityHolder<MushroomMonsterEntity> holder;

    protected MushroomMonsterEntity(class_1299<? extends class_1314> entityType, class_1937 world) {
        this(entityType, world, MODEL);
    }

    protected MushroomMonsterEntity(class_1299<? extends class_1314> entityType, class_1937 world, Model hairballModel) {
        super(entityType, world);
        this.hairballModel = hairballModel;
        this.method_5941(class_7.field_18, 0.0F);
        this.init();
    }

    @Override
    protected void method_5959() {
        super.method_5959();
        this.field_6201.method_6277(0, new class_1347(this));
        this.field_6201.method_6277(1, new class_1366(this, 1.0, true));
        this.field_6201.method_6277(5, new class_1376(this));
        this.field_6201.method_6277(6, new class_1394(this, 0.8));
        this.field_6201.method_6277(10, new class_1361(this, class_1657.class, 16.0f));

        this.field_6185.method_6277(2, new class_1400<>(this, class_1657.class, true));
    }

    @Override
    public boolean method_6121(class_3218 world, class_1297 target) {
        if (target instanceof class_1309) {
            ((class_1309) target).method_6092(new class_1293(class_1294.field_5899, 10 * 20));
            ((class_1309) target).method_6092(new class_1293(class_1294.field_5916, 15 * 20));
        }
        return super.method_6121(world, target);
    }

    private void init() {
        this.holder = new LivingEntityHolder<>(this, this.hairballModel);
        EntityAttachment.ofTicking(this.holder, this);
        ELEMENTS.put(this, holder);
    }

    @Override
    public void method_5773() {
        super.method_5773();
        if (this.field_6012 % 2 == 0) {
            AnimationHelper.updateWalkAnimation(this, this.holder);
            AnimationHelper.updateHurtVariant(this, this.holder);
        }
    }

    public static class_5132 createAttributes() {
        return class_1309.method_26827()
                .method_26868(class_5134.field_23716, 30)
                .method_26868(class_5134.field_23719, 0.2)
                .method_26868(class_5134.field_23721, 3.5)
                .method_26868(class_5134.field_23717, 15)
                .method_26866();
    }

    @Override
    public void method_6078(class_1282 damageSource) {
        super.method_6078(damageSource);
        class_1937 world = this.method_37908();
        if (!world.method_8608() && world instanceof class_3218 serverWorld) {
            class_5819 random = class_5819.method_43047();
            int count = random.method_43048(4);
            class_1792 item = random.method_43056() ? class_1802.field_17517 : class_1802.field_17516;
            class_1799 stack = new class_1799(item, count);
            class_1542 itemEntity = new class_1542(serverWorld, this.method_23317(), this.method_23318(), this.method_23321(), stack, 0, 0.1, 0);
            world.method_8649(itemEntity);
        }
    }

    @Override
    public AnimatedEntityHolder getHolder() {
        return this.holder;
    }
}

==> reverie_dreams-0.4.6%2B1.21.7%2Bbeta-sources.jar: cc/thonly/reverie_dreams/entity/MushroomMonsterEntity.java <==
package cc.thonly.reverie_dreams.entity;

import cc.thonly.reverie_dreams.ReverieDreams;
import cc.thonly.reverie_dreams.util.entity.AnimationHelper;
import cc.thonly.reverie_dreams.util.entity.ModelUtil;
import de.tomalbrc.bil.api.AnimatedEntity;
import de.tomalbrc.bil.api.AnimatedEntityHolder;
import de.tomalbrc.bil.core.holder.entity.EntityHolder;
import de.tomalbrc.bil.core.holder.entity.living.LivingEntityHolder;
import de.tomalbrc.bil.core.model.Model;
import eu.pb4.polymer.virtualentity.api.attachment.EntityAttachment;
import lombok.Getter;
import net.minecraft.class_1282;
import net.minecraft.class_1293;
import net.minecraft.class_1294;
import net.minecraft.class_1297;
import net.minecraft.class_1299;
import net.minecraft.class_1309;
import net.minecraft.class_1314;
import net.minecraft.class_1347;
import net.minecraft.class_1361;
import net.minecraft.class_1366;
import net.minecraft.class_1376;
import net.minecraft.class_1394;
import net.minecraft.class_1400;
import net.minecraft.class_1542;
import net.minecraft.class_1657;
import net.minecraft.class_1792;
import net.minecraft.class_1799;
import net.minecraft.class_1802;
import net.minecraft.class_1937;
import net.minecraft.class_3218;
import net.minecraft.class_5132;
import net.minecraft.class_5134;
import net.minecraft.class_5819;
import net.minecraft.class_7;
import java.util.WeakHashMap;

@Getter
public class MushroomMonsterEntity extends class_1314 {

    public MushroomMonsterEntity(class_1299<MushroomMonsterEntity> mushroomMonsterEntityEntityType, class_1937 level) {
        super(mushroomMonsterEntityEntityType, level);
        this.method_5941(class_7.field_18, 0.0F);
    }

    @Override
    protected void method_5959() {
        super.method_5959();
        this.field_6201.method_6277(0, new class_1347(this));
        this.field_6201.method_6277(1, new class_1366(this, 1.0, true));
        this.field_6201.method_6277(5, new class_1376(this));
        this.field_6201.method_6277(6, new class_1394(this, 0.8));
        this.field_6201.method_6277(10, new class_1361(this, class_1657.class, 16.0f));

        this.field_6185.method_6277(2, new class_1400<>(this, class_1657.class, true));
    }

    @Override
    public boolean method_6121(class_3218 world, class_1297 target) {
        if (target instanceof class_1309) {
            ((class_1309) target).method_6092(new class_1293(class_1294.field_5899, 10 * 20));
            ((class_1309) target).method_6092(new class_1293(class_1294.field_5916, 15 * 20));
        }
        return super.method_6121(world, target);
    }

    public static class_5132 createAttributes() {
        return class_1309.method_26827()
                .method_26868(class_5134.field_23716, 30)
                .method_26868(class_5134.field_23719, 0.2)
                .method_26868(class_5134.field_23721, 3.5)
                .method_26868(class_5134.field_23717, 15)
                .method_26866();
    }

    @Override
    public void method_6078(class_1282 damageSource) {
        super.method_6078(damageSource);
        class_1937 world = this.method_37908();
        if (!world.method_8608() && world instanceof class_3218 serverWorld) {
            class_5819 random = class_5819.method_43047();
            int count = random.method_43048(4);
            class_1792 item = random.method_43056() ? class_1802.field_17517 : class_1802.field_17516;
            class_1799 stack = new class_1799(item, count);
            class_1542 itemEntity = new class_1542(serverWorld, this.method_23317(), this.method_23318(), this.method_23321(), stack, 0, 0.1, 0);
            world.method_8649(itemEntity);
        }
    }

}
